@@ -33,17 +33,18 @@
 # response
 # ############################################################
 # #####################Obtain observations####################
-# with daniel.pinacho
-# action <- "API_getObservationsFromDataset"
-# parameters <- list(
-#   oblender = 1,
-#   token = "67dTvR8KVRM044s9ldE94IgFc5HF3q",
-#   id_user = "5d48b439275b3f05db0feee2",
-#   id_dataset = "5d533b864b81b70af19bdc4c"
-# )
-#
-# response <- openblender::call(action, parameters)
-# dfr <- response$sample
-# head(dfr)
-# nrow(dfr)
+action <- "API_getObservationsFromDataset"
+parameters <- list(
+  oblender = 1,
+  blends = list(list(id_blend = "5d976070f86334ee1cfc14f0", blend_type = "ts", restriction = "None", blend_class = "closest_observation")),
+  token = "67dTvR8KVRM044s9ldE94IgFc5HF3q",
+  id_user = "5d48b439275b3f05db0feee2",
+  id_dataset = "5d533b864b81b70af19bdc4c"
+)
+
+response <- openblender::call(action, parameters)
+dfr <- response$sample
+head(dfr)
+nrow(dfr)
 # dfr
+
